@@ -2,23 +2,23 @@
 
 __author__ = """Rex Wang"""
 __email__ = '1073853456@qq.com'
-__version__ = '0.2.3'
+__version__ = '0.3.1'
 
-import openai
 import os
-from .chattool import Chat, Resp
+from .chattool import Chat, Resp, chat_completion
 from .proxy import proxy_on, proxy_off, proxy_status
 
 # read API key from the environment variable
 if os.environ.get('OPENAI_API_KEY') is not None:
-    apikey = os.environ.get('OPENAI_API_KEY')
-    if not apikey.startswith("sk-"):
+    api_key = os.environ.get('OPENAI_API_KEY')
+    if not api_key.startswith("sk-"):
         print("Warning: The default environment variable `OPENAI_API_KEY` is not a valid API key.")
-    openai.api_key = apikey
+else:
+    api_key = None
 
 def show_apikey():
-    if openai.api_key is not None:
-        print(f"API key:\t{openai.api_key}")
+    if api_key is not None:
+        print(f"API key:\t{api_key}")
     else:
         print("API key is not set!")
 
